==> svm-1.0.0-rc8-sources.jar: com/oracle/svm/hosted/c/info/EnumLookupInfo.java <==
/*
 * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.hosted.c.info;

import jdk.vm.ci.meta.ResolvedJavaMethod;

public class EnumLookupInfo extends ElementInfo {

    private final ResolvedJavaMethod annotatedMethod;

    public EnumLookupInfo(ResolvedJavaMethod annotatedMethod) {
        super(annotatedMethod.getName());
        this.annotatedMethod = annotatedMethod;
    }

    @Override
    public Object getAnnotatedElement() {
        return annotatedMethod;
    }

    @Override
    public void accept(InfoTreeVisitor visitor) {
        visitor.visitEnumLookupInfo(this);
    }
}

==> svm-23.0.1-sources.jar: com/oracle/svm/hosted/c/info/EnumLookupInfo.java <==
/*
 * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.hosted.c.info;

import jdk.vm.ci.meta.ResolvedJavaMethod;

public class EnumLookupInfo extends ElementInfo {

    private final ResolvedJavaMethod annotatedMethod;

    public EnumLookupInfo(ResolvedJavaMethod annotatedMethod) {
        super(annotatedMethod.getName());
        this.annotatedMethod = annotatedMethod;
    }

    @Override
    public ResolvedJavaMethod getAnnotatedElement() {
        return annotatedMethod;
    }

    @Override
    public void accept(InfoTreeVisitor visitor) {
        visitor.visitEnumLookupInfo(this);
    }
}
